@@ -26,7 +26,7 @@ pygtk.require('2.0')
 import gtk
 import gtk.gdk
 import calendar
-import os,sys
+import os
 import os.path
 import utility
 from xml.dom.minidom import getDOMImplementation, parse
@@ -34,9 +34,12 @@ from xml.parsers.expat import ExpatError
 from string import strip, lower
 
 DATA_DIR="/usr/share/jalali-calendar"
-mon_name = ["فروردین","اردیبهشت","خرداد","تیر","مرداد","شهریور","مهر","آبان","آذر","دی","بهمن","اسفند"]
+mon_name = ["فروردین","اردیبهشت","خرداد","تیر","مرداد","شهریور"
+            ,"مهر","آبان","آذر","دی","بهمن","اسفند"]
+milady_monname = ["January","February","March","April","May","June","July",
+                  "August","September","October","November","December"]
 extrafile = "/.jcal_extra.xml"
-imagelist={0:"balloons-aj.png",1:"marid.png",2:"shabdar.png",3:None}
+imagelist={0:"balloons-aj.png",1:"marid.png",2:"shabdar.png",3:"cday.png"}
 
 def _get_text(nodelist):
     rc = u""
@@ -47,7 +50,7 @@ def _get_text(nodelist):
     return name,rc.strip()
 
 def get_home():
-        return os.environ.get('HOME', '')
+    return os.environ.get('HOME', '')
 
 def convert_to_str(num):
     s = str(num)
@@ -97,7 +100,7 @@ class wmonth:
 
 class Main(gtk.Window):
     ww = 300
-    wh = 75
+    wh = 70
     wh2 = 0
     def change_db(self,year):
         calfile=DATA_DIR+"/"+str(year)+".xml"
@@ -123,47 +126,17 @@ class Main(gtk.Window):
                         if ((name=="desc") and (find==True) ):
                             return data
         return None
+   
+    def __init__(self,year,month,day,size):
 
-    def getcustomfile(self):
-        calfile=get_home()+extrafile
-        if (os.path.isfile(calfile)):
-            tmp = parse(calfile).documentElement
-            self.customdb=tmp.getElementsByTagName("day")
-        else:
-            self.customdb=None
-    
-    def loadcustomlist(self):
-        if (self.customdb==None):
-            return None
-        self.full_list = []
-        for record in self.customdb:
-            list = []
-            for element in record.childNodes:
-                if element.nodeType != element.TEXT_NODE:
-                    if element.nodeType != element.TEXT_NODE:
-                        name, data = _get_text(element)
-                        if (name=="num"):
-                            sp=data.split("/")
-                            list.append(int(sp[0]))
-                            list.append(int(sp[1]))
-                        if (name=="kind"):
-                            list.append(int(data))
-                        if (name=="desc"):
-                            list.append(data)
-            self.full_list.append(list)
-
-    def __init__(self,year,month,day):
-        global DATA_DIR
-        DATA_DIR=sys.path[0]
-        
-        self.full_list = []
         self.db = None
         self.db2 = None
-        self.customdb=None
         
         self.change_db(year)
-        self.getcustomfile()
-        self.loadcustomlist()
+        #csize = [(146,300),(180,235),(205,335),(290,435)]
+        #self.wh,self.ww = csize[size]
+        
+        self.full_list = get_customday(month,day)
         gtk.Window.__init__(self)
         self.set_keep_above(True)
         self.set_position(gtk.WIN_POS_MOUSE)
@@ -184,11 +157,10 @@ class Main(gtk.Window):
         self.box1.set_border_width(5)
         self.vbox2.pack_start(self.box1,0,0,0)
         self.hbox3=gtk.HBox()
-        self.date_label=gtk.Label(str(year)+"/"+str(month)+"/"+str(day))
+        self.date_label=gtk.Label()
         self.date_label.set_selectable(True)
         self.hbox3.pack_start(self.date_label,1,1,0)
-        y,m,d = utility.jalali_to_milady(year,month,day)
-        self.date_labelm=gtk.Label(str(y)+"/"+str(m)+"/"+str(d))
+        self.date_labelm=gtk.Label()
         self.date_labelm.set_selectable(True)
         self.hbox3.pack_start(self.date_labelm,1,1,0)
         
@@ -230,7 +202,7 @@ class Main(gtk.Window):
         self.header.arrow_left.connect("clicked",self.year_prev)
         self.header.arrow_right.connect("clicked",self.year_next)
         #self.header.hbox.show_all()
-        self.cal=calendar.pcalendar(year,month,day,DATA_DIR,self.full_list)
+        self.cal=calendar.pcalendar(year,month,day,DATA_DIR,loadcustomlist(),size)
         self.cal.connect("month-change",self.monthchange)
         self.cal.connect("day-change",self.daychange)
         #self.cal.show()
@@ -243,6 +215,7 @@ class Main(gtk.Window):
         self.month=month
         self.year=year
         self.box2.show_all()
+        self.change_lable(self.day)
         
         slabel=self.get_dayname(month,day)
         if (slabel!=None):
@@ -255,16 +228,16 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2 = 0
     
-        self.getcustomfile()
-        result = self.loadcustomday()
-        if (result ==True):
+        
+        if (self.full_list != None):
+            self.loadcustomday(self.month, self.day)
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
             self.customday.hide()
             
     def checkresize(self,obj,data=None):
         self.wh2=data[1]-6
-        self.resize(300,self.wh+data[1]-6)
+        self.resize(self.ww,self.wh+data[1]-6)
 
     def checkresize_c(self,obj,data=None):
         self.resize(self.ww,self.wh+self.wh2+data[1]-6)
@@ -272,9 +245,7 @@ class Main(gtk.Window):
     def monthchange(self,obj=None,month=None,year=None):
         self.header.yearnum.set_label("<b>"+convert_to_str(year)+"</b>")
         self.header.monthname.set_label(' <b>'+mon_name[month-1]+'</b> ')
-        self.date_label.set_label(str(year)+"/"+str(month)+"/"+str(self.day))
-        y,m,d = utility.jalali_to_milady(year,month,self.day)
-        self.date_labelm.set_label(str(y)+"/"+str(m)+"/"+str(d))
+        self.change_lable(self.day)
 
         if (self.year!=year):
             self.change_db(year)
@@ -289,7 +260,7 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2=0
 
-        result = self.loadcustomday()
+        result = self.loadcustomday(self.month,self.day)
         if (result ==True):
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
@@ -300,9 +271,7 @@ class Main(gtk.Window):
         
         
     def daychange(self,obj=None,month=None,year=None,day=None):
-        self.date_label.set_label(str(year)+"/"+str(month)+"/"+str(day))
-        y,m,d = utility.jalali_to_milady(year,month,day)
-        self.date_labelm.set_label(str(y)+"/"+str(m)+"/"+str(d))
+        self.change_lable(day)
 
         self.day=day
         self.month=month
@@ -319,7 +288,7 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2=0
 
-        result = self.loadcustomday()
+        result = self.loadcustomday(self.month,self.day)
         if (result ==True):
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
@@ -341,9 +310,7 @@ class Main(gtk.Window):
         else:
             self.dayname.hide()
         self.year=year
-        self.date_label.set_label(str(year)+"/"+str(month)+"/"+str(self.day))
-        y,m,d = utility.jalali_to_milady(year,month,self.day)
-        self.date_labelm.set_label(str(y)+"/"+str(m)+"/"+str(d))
+        self.change_lable(self.day)
         slabel=self.get_dayname(month,self.day)
         if (slabel!=None):
             buf = self.dayname.get_buffer()
@@ -354,7 +321,7 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2=0
 
-        result = self.loadcustomday()
+        result = self.loadcustomday(self.month,self.day)
         if (result ==True):
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
@@ -374,9 +341,7 @@ class Main(gtk.Window):
         if (self.year!=year):
             self.change_db(year)
         self.year=year
-        self.date_label.set_label(str(year)+"/"+str(month)+"/"+str(self.day))
-        y,m,d = utility.jalali_to_milady(year,month,self.day)
-        self.date_labelm.set_label(str(y)+"/"+str(m)+"/"+str(d))
+        self.change_lable(self.day)
         slabel=self.get_dayname(month,self.day)
         if (slabel!=None):
             buf = self.dayname.get_buffer()
@@ -387,7 +352,7 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2=0
 
-        result = self.loadcustomday()
+        result = self.loadcustomday(self.month,self.day)
         if (result ==True):
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
@@ -402,9 +367,7 @@ class Main(gtk.Window):
         year=self.cal.get_year()
         self.header.yearnum.set_label(' <b>'+convert_to_str(year)+'</b> ')
         self.year=year
-        self.date_label.set_label(str(year)+"/"+str(self.month)+"/"+str(self.day))
-        y,m,d = utility.jalali_to_milady(year,self.month,self.day)
-        self.date_labelm.set_label(str(y)+"/"+str(m)+"/"+str(d))
+        self.change_lable(self.day)
         self.change_db(year)
         slabel=self.get_dayname(self.month,self.day)
         if (slabel!=None):
@@ -416,7 +379,7 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2=0
 
-        result = self.loadcustomday()
+        result = self.loadcustomday(self.month,self.day)
         if (result ==True):
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
@@ -425,15 +388,13 @@ class Main(gtk.Window):
         if (result==False)and(slabel==None):
             self.resize(self.ww,self.wh)
         self.date_label.set_label(str(year)+"/"+str(self.month)+"/"+str(self.day))
-
-    def year_prev(self,obj,data=None):
+    
+    def year_prev(self, obj, data=None):
         self.cal.prev_year()
         year=self.cal.get_year()
         self.header.yearnum.set_label(' <b>'+convert_to_str(year)+'</b> ')
         self.year=year
-        self.date_label.set_label(str(year)+"/"+str(self.month)+"/"+str(self.day))
-        y,m,d = utility.jalali_to_milady(year,self.month,self.day)
-        self.date_labelm.set_label(str(y)+"/"+str(m)+"/"+str(d))
+        self.change_lable(self.day)
         self.change_db(year)
         slabel=self.get_dayname(self.month,self.day)
         if (slabel!=None):
@@ -445,7 +406,7 @@ class Main(gtk.Window):
             self.dayname.hide()
             self.wh2=0
 
-        result = self.loadcustomday()
+        result = self.loadcustomday(self.month,self.day)
         if (result ==True):
             self.resize(self.ww,self.wh+self.wh2+self.customday.get_visible_rect()[3])
         else:
@@ -455,40 +416,93 @@ class Main(gtk.Window):
             self.resize(self.ww,self.wh)
         self.date_label.set_label(str(year)+"/"+str(self.month)+"/"+str(self.day))
 
-    def loadcustomday(self):
-        if (self.customdb==None):
-            return None
-        find=False
-        for record in self.customdb:
-            list = []
-            for element in record.childNodes:
-                if element.nodeType != element.TEXT_NODE:
-                    if element.nodeType != element.TEXT_NODE:
-                        name, data = _get_text(element)
-                        if (name=="num"):
-                            sp=data.split("/")
-                            if ( (int(sp[0])==self.month)and(int(sp[1])==self.day) ):
-                                find = True
-                                list.append(sp[0])
-                                list.append(sp[1])
-                        if (find==True)and(name=="kind"):
-                            list.append(data)
-                        if (find==True)and(name=="desc"):
-                            list.append(data)
-            if find==True:
-                break
-        if find==True:
+    def change_lable(self, day):
+        year = self.cal.get_year()
+        month=self.cal.get_month()
+        y,m,d = utility.jalali_to_milady(year,month,day)
+        text = "%s/%s (%s) /%s" % (y, milady_monname[m-1], m, d)
+        self.date_labelm.set_label(text)
+        text = "%s/%s/%s" % (year, month, day)
+        self.date_label.set_label(text)
+
+    def loadcustomday(self,mm,dd):
+        find = False
+        alllist=get_customday(mm,dd)
+        if alllist!=None:
+            find = True
             self.customstor.clear()
-            try:
-                pix = gtk.Image()
-                file = DATA_DIR+"/"+imagelist.get(int(list[2]))
-                pix.set_from_file(file)
-                p=pix.get_pixbuf()
-            except:
-                p=None
-            self.customstor.append([p,list[3]])
+            for element in alllist:
+                try:
+                    pix = gtk.Image()
+                    file = DATA_DIR+"/"+imagelist.get(int(element[2]))
+                    pix.set_from_file(file)
+                    p=pix.get_pixbuf()
+                except:
+                    p=None
+                self.customstor.append([p,element[3]])
             self.customday.show()
         return find
         
     def quit(self,obj):
-        self.destroy()
\ No newline at end of file
+        self.destroy()
+
+def getcustomfile():
+    calfile=get_home()+extrafile
+    if (os.path.isfile(calfile)):
+        tmp = parse(calfile).documentElement
+        return tmp.getElementsByTagName("day")
+    else:
+        return None
+
+def loadcustomlist():
+    customdb = getcustomfile()
+    if customdb==None:
+        return None 
+    full_list = []
+    for record in customdb:
+        list = []
+        for element in record.childNodes:
+            if element.nodeType != element.TEXT_NODE:
+                if element.nodeType != element.TEXT_NODE:
+                    name, data = _get_text(element)
+                    if (name=="num"):
+                        sp=data.split("/")
+                        list.append(int(sp[0]))
+                        list.append(int(sp[1]))
+                    if (name=="kind"):
+                        list.append(int(data))
+                    if (name=="desc"):
+                        list.append(data)
+        full_list.append(list)
+    return full_list
+
+def get_customday(mm,dd,fill=False):
+    customdb = getcustomfile()
+    if customdb==None:
+        return None
+    alllist = []
+    
+    for record in customdb:
+        list = []
+        find = False
+        for element in record.childNodes:
+            if element.nodeType != element.TEXT_NODE:
+                if element.nodeType != element.TEXT_NODE:
+                    name, data = _get_text(element)
+                    if (name=="num"):
+                        sp=data.split("/")
+                        if ( (int(sp[0])==mm)and(int(sp[1])==dd) ):
+                            find = True
+                            list.append(sp[0])
+                            list.append(sp[1])
+                    if (find==True)and(name=="kind"):
+                        list.append(data)
+                    if (find==True)and(name=="desc"):
+                        list.append(data)
+        if list!=[]:
+            alllist.append(list)
+    if alllist!=[]:
+        return alllist
+    else:
+        return None
+    
\ No newline at end of file
