@@ -1,4 +1,5 @@
-##
+#!/usr/bin/env python
+###
 #    
 #    Copyright (C) 2007  Mola Pahnadayan
 #
@@ -23,4 +24,7 @@ holiday = { 1386:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[1,17],
                   [11,22],[12,9],[12,17],[12,18],[12,29]],
 	    1387:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[3,14],[3,15],[3,18],[4,26],[5,9],[5,27],
                   [7,1],[7,10],[8,4],[9,19],[9,27],[10,17],[10,18],
-                  [11,22],[11,28],[12,6],[12,8],[12,25],[12,29]] }
+                  [11,22],[11,28],[12,6],[12,8],[12,25],[12,29]],
+		1388:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[3,7],[3,14],[3,15],[4,15],[4,29],[5,16],
+                  [6,20],[6,29],[7,22],[9,7],[9,15],[10,5],[10,6],
+                  [11,16],[11,22],[11,24],[11,26],[12,13],[12,29]] }
