@@ -33,6 +33,7 @@ import utility
 import time
 import datetime
 import gconf
+import pynotify
 import caldialog
 import birthdaydialog
 import holiday
@@ -52,23 +53,23 @@ def convert_to_str(num):
 class Jcalendar:
     timeout_interval = 1000
     def timeout_callback(self,obj=None,Time=None):
-		jdate=utility.convert_to_jalali(time.time())
-		self.year=jdate[0]
-		self.month=jdate[1]
-		self.day=jdate[2]
-		if self.show_time==True:
-			self.set_time()
-		if self.lastday!=jdate[2]:
-			if self.get_day_details():
-				backimage = self.iamge_composite(PIXDIR+"bx-02.png",PIXDIR+"x-"+str(jdate[2])+".png")
-			else:
-				backimage = self.iamge_composite(PIXDIR+"bx-01.png",PIXDIR+"x-"+str(jdate[2])+".png")
-			self.image.set_from_pixbuf(backimage)
-			self.tbutton.set_image(self.image)
-        		self.tooltips.set_tip(self.tbutton,convert_to_str(self.day)+" "+mon_name[self.month-1]+" "+convert_to_str(self.year))
+        jdate=utility.convert_to_jalali(time.time())
+        self.year=jdate[0]
+        self.month=jdate[1]
+        self.day=jdate[2]
+        if self.show_time==True:
+            self.set_time()
+        if self.lastday!=jdate[2]:
+            if self.get_day_details():
+                backimage = self.iamge_composite(PIXDIR+"bx-02.png",PIXDIR+"x-"+str(jdate[2])+".png")
+            else:
+                backimage = self.iamge_composite(PIXDIR+"bx-01.png",PIXDIR+"x-"+str(jdate[2])+".png")
+            self.image.set_from_pixbuf(backimage)
+            self.tbutton.set_image(self.image)
+            self.tooltips.set_tip(self.tbutton,convert_to_str(self.day)+" "+mon_name[self.month-1]+" "+convert_to_str(self.year))
 
-		self.lastday = jdate[2]
-		return True
+        self.lastday = jdate[2]
+        return True
 		
     def iamge_composite(self,add1,add2):
 		pixbuf1 = gtk.gdk.pixbuf_new_from_file(add2)
@@ -83,15 +84,16 @@ class Jcalendar:
 		
     def cal_show(self,obj,data=None):
 		if obj.get_active():
-			self.dialog=caldialog.Main(self.year,self.month,self.day)
+			self.dialog=caldialog.Main(self.year,self.month,self.day,self.cal_size)
 			self.dialog.show()
 		else:
 			self.dialog.destroy()
 
     def about_show(self,obj=None,data=None):
-		about = gnome.ui.About("Jalali calendar applet","1.6.5","GPL",
+		about = gnome.ui.About("Jalali calendar applet","1.6.8","GPL",
 							   "Applet to check jalali calendar",
-							   ["نویسنده مولا پهنادایان"])
+							   ["نویسنده مولا پهنادایان","\n با تشکر از",
+                                "هدایت وطن‌خواه","حسن شفیعی منفرد"])
 		about.show()
 	
     def birthday_add(self,obj=None,data=None):
@@ -159,6 +161,7 @@ class Jcalendar:
         self.show_time=self.conf_client.get_bool("/apps/jcalendar/show_time")
         self.type=show_time=self.conf_client.get_int("/apps/jcalendar/time_type")
         self.show_sec=self.conf_client.get_bool("/apps/jcalendar/show_sec")
+        self.cal_size=self.conf_client.get_int("/apps/jcalendar/cal_size")
         if self.show_time==False:
             self.show_sec=False
             self.tbutton.set_label("")
@@ -166,11 +169,29 @@ class Jcalendar:
             self.lastmin -= 1
             self.set_time()
 
+    def print_day(self,obj=None,Time=None):
+        
+        pynotify.init("Jcalendar")
+        list=caldialog.get_customday(self.month,self.day)
+        if list == None:
+            return False
+        slist= ""
+        for element in list:
+            slist+=element[3]+'\n'
+        n = pynotify.Notification("امروز", slist)
+        n.set_urgency(pynotify.URGENCY_NORMAL )
+        n.set_timeout(3000)
+        n.set_icon_from_pixbuf(self.image.get_pixbuf())
+        n.attach_to_widget(self.image)
+        if not n.show():
+            print "Can't create notify"
+        return False
+
 
     def __init__(self,applet,iid):
         self.propxml="""
 		<popup name="button3">
-		<menuitem name="Item1" verb="Customday" label="_Custom day" pixtype="stock" pixname="gtk-add"/>
+		<menuitem name="Item1" verb="Customday" label="_Event day" pixtype="stock" pixname="gtk-add"/>
 		<menuitem name="Item2" verb="Preferences" label="_Preferences"  pixtype="stock" pixname="gtk-preferences"/>
 		<menuitem name="Item3" verb="About" label="_About..." pixtype="stock" pixname="gnome-stock-about"/>
 		</popup>"""
@@ -184,6 +205,7 @@ class Jcalendar:
         self.show_time=self.conf_client.get_bool("/apps/jcalendar/show_time")
         self.type=show_time=self.conf_client.get_int("/apps/jcalendar/time_type")
         self.show_sec=self.conf_client.get_bool("/apps/jcalendar/show_sec")
+        self.cal_size=self.conf_client.get_int("/apps/jcalendar/cal_size")
         
         jdate=utility.convert_to_jalali(time.time())
 		
@@ -215,6 +237,7 @@ class Jcalendar:
         self.applet.show_all()
         self.applet.set_background_widget(self.applet)
         gobject.timeout_add(self.timeout_interval,self.timeout_callback, self)
+        gobject.timeout_add(6000,self.print_day, self)
 		
 def jcalendar_applet_factory(applet, iid):
 	Jcalendar(applet,iid)
